@@ -6,8 +6,7 @@ PROJDIR = os.path.abspath(os.path.dirname(__file__))
 import sys
 import logging
 from liquidluck.options import g, settings
-from liquidluck.utils import import_object, walk_dir
-
+from liquidluck.utils import import_object, walk_dir, parse_settings
 from liquidluck.writers.base import load_jinja, find_theme
 
 
@@ -48,24 +47,31 @@ def create_settings(filepath):
     f.close()
 
 
-def find_settings():
+def find_settings(directory=None):
+    if not directory:
+        directory = os.getcwd()
+
     config = [
         'settings.yml', 'settings.json', 'settings.yaml', 'settings.py',
     ]
 
     for f in config:
-        path = os.path.join(os.getcwd(), f)
+        path = os.path.join(directory, f)
         if os.path.exists(path):
             return path
 
     return None
 
 
-def load_settings(path):
+def load_settings(path=None):
     if not path:
         path = find_settings()
 
-    def update_settings(config):
+    def update_settings(arg):
+        if isinstance(arg, dict):
+            config = arg
+        else:
+            config = parse_settings(arg)
         for key in config:
             setting = config[key]
             if isinstance(setting, dict) and key in settings:
@@ -73,45 +79,9 @@ def load_settings(path):
             else:
                 settings[key] = setting
 
-    def load_py_settings(path):
-        config = {}
-        execfile(path, {}, config)
-        update_settings(config)
-
-    def load_yaml_settings(path):
-        from yaml import load
-        try:
-            from yaml import CLoader
-            MyLoader = CLoader
-        except ImportError:
-            from yaml import Loader
-            MyLoader = Loader
-
-        config = load(open(path), MyLoader)
-        update_settings(config)
-
-    def load_json_settings(path):
-        try:
-            import json
-        except ImportError:
-            import simplejson
-            json = simplejson
-
-        f = open(path)
-        content = f.read()
-        f.close()
-        config = json.loads(content)
-        update_settings(config)
-
     #: preload default config
-    load_py_settings(os.path.join(PROJDIR, 'tools', '_settings.py'))
-
-    if path.endswith('.py'):
-        load_py_settings(path)
-    elif path.endswith('.json'):
-        load_json_settings(path)
-    else:
-        load_yaml_settings(path)
+    update_settings(os.path.join(PROJDIR, 'tools', '_settings.py'))
+    update_settings(path)
 
     g.output_directory = os.path.abspath(settings.config.get('output'))
     g.static_directory = os.path.abspath(settings.config.get('static'))
