@@ -36,7 +36,7 @@ from pygments.formatters import HtmlFormatter
 from pygments.lexers import get_lexer_by_name
 
 from liquidluck.readers.base import BaseReader
-from liquidluck.options import settings, g
+from liquidluck.options import settings
 from liquidluck.utils import to_unicode, cjk_nowrap, import_object
 
 
@@ -45,9 +45,7 @@ class MarkdownReader(BaseReader):
 
     def render(self):
         f = open(self.filepath)
-
-        if g.detail_logging:
-            logging.info('read ' + self.relative_filepath)
+        logging.debug('read ' + self.relative_filepath)
 
         header = ''
         body = ''
