@@ -21,6 +21,7 @@ except ImportError:
     WebSocketHandler = object
 
 
+HOST = '127.0.0.1'
 PORT = 8000
 ROOT = os.path.abspath('.')
 PERMALINK = 'html'
@@ -33,7 +34,10 @@ def config(port=None, root=None, permalink=None):
     global PORT
     global ROOT
     global PERMALINK
-    if port:
+
+    if port and ':' in port:
+        HOST, PORT = port.split(':')
+    elif port:
         PORT = port
 
     if root:
@@ -171,7 +175,7 @@ class LiveReloadHandler(WebSocketHandler):
                 self.reload_browser()
             return
 
-        if self._is_changed(g.source_directory):
+        if self._is_changed(g.source_directory, 4):
             # clean posts
             g.public_posts = []
             g.secure_posts = []
@@ -200,7 +204,7 @@ class LiveReloadHandler(WebSocketHandler):
                 logging.error('Error sending message', exc_info=True)
                 LiveReloadHandler.waiters.remove(waiter)
 
-    def _is_changed(self, path):
+    def _is_changed(self, path, flags=0):
         def is_file_changed(path):
             if not os.path.isfile(path):
                 return False
@@ -210,11 +214,11 @@ class LiveReloadHandler(WebSocketHandler):
 
             ignores = theme.get('reload_ignore') or []
             ignores.extend(['.pyc', '.pyo', '.swp'])
-            if ext in ignores:
+            if flags > 0 and ext in ignores:
                 return False
 
             matches = theme.get('reload_match') or []
-            if matches and ext not in matches:
+            if flags > 1 and ext not in matches:
                 return False
 
             modified = int(os.stat(path).st_mtime)
@@ -261,25 +265,38 @@ class IndexHandler(RequestHandler):
         if body is None:
             self.send_error(404)
             return
-        body = body.replace(
-            '</head>', '<script src="/livereload.js"></script></head>'
-        )
+        ua = self.request.headers.get("User-Agent", 'bot').lower()
+        if 'msie' not in ua:
+            body = body.replace(
+                '</head>', '<script src="/livereload.js"></script></head>'
+            )
         # disable google analytics
         body = body.replace('google-analytics.com/ga.js', '')
         self.write(body)
 
 
-def start_server():
-    if not isinstance(PORT, int) and ':' in PORT:
-        host, port = PORT.split(':')
-        port = int(port)
-    else:
-        host = '127.0.0.1'
-        port = int(PORT)
+class ThemeStaticHandler(RequestHandler):
+    def get(self, filepath):
+        abspath = os.path.join(g.theme_directory, 'static', filepath)
+        mime_type, encoding = mimetypes.guess_type(abspath)
+        if not mime_type:
+            mime_type = 'text/html'
 
+        self.set_header('Content-Type', mime_type)
+        if not os.path.exists(abspath):
+            self.send_error(404)
+            return
+
+        f = open(abspath)
+        for line in f:
+            self.write(line)
+        f.close()
+
+
+def start_server():
     if RequestHandler is object:
-        logging.info('Start server at %s:%s' % (host, port))
-        make_server(host, port, wsgi_app).serve_forever()
+        logging.info('Start server at %s:%s' % (HOST, PORT))
+        make_server(HOST, int(PORT), wsgi_app).serve_forever()
     else:
         import tornado.web
         if g.output_directory == ROOT:
@@ -290,11 +307,12 @@ def start_server():
         handlers = [
             (r'/livereload', LiveReloadHandler),
             (r'/livereload.js', LiveReloadJSHandler),
+            (r'/theme/(.*)', ThemeStaticHandler),
             (r'(.*)', IndexHandler),
         ]
-        app = tornado.web.Application(handlers=handlers, default_host=host)
-        app.listen(port)
-        logging.info('Start server at %s:%s' % (host, port))
+        app = tornado.web.Application(handlers=handlers, default_host=HOST)
+        app.listen(int(PORT))
+        logging.info('Start server at %s:%s' % (HOST, PORT))
         tornado.ioloop.IOLoop.instance().start()
 
 
