@@ -1,4 +1,5 @@
 import os
+from liquidluck.options import g
 from liquidluck.utils import to_unicode
 
 
@@ -106,11 +107,14 @@ def install(keyword=None, widely=False):
         repo = 'https://github.com/%(username)s/liquidluck-theme-%(name)s' \
                 % theme
     if widely:
-        output = os.path.expanduser('~/.liquidluck-themes/%s' % keyword)
+        output = os.path.join(g.theme_gallery, keyword)
     else:
         output = '_themes/%s' % keyword
     import subprocess
-    subprocess.call(['git', 'clone', repo, output])
+    if os.path.exists(output):
+        subprocess.call(['git', 'pull'], cwd=output)
+    else:
+        subprocess.call(['git', 'clone', repo, output])
 
 
 if __name__ == '__main__':
